@@ -103,7 +103,10 @@
     Updated by      Richard Gooch   21-NOV-1999: Added compatibility entries
   for joystick devices.
 
-    Last updated by Richard Gooch   6-DEC-1999: Change directory to devfs FS.
+    Updated by      Richard Gooch   6-DEC-1999: Change directory to devfs FS.
+
+    Last updated by Richard Gooch   9-DEC-1999: Support compiling with 2.2.x
+  kernels.
 
 
 */
@@ -130,8 +133,15 @@
 #include <errno.h>
 #include <karma.h>
 
+#ifndef IDE6_MAJOR        /*  In case we're building with an ancient kernel  */
+#  define IDE6_MAJOR      88
+#  define IDE7_MAJOR      89
+#  define IDE8_MAJOR      90
+#  define IDE9_MAJOR      91
+#endif
 
-#define VERSION "1.2.12"
+
+#define VERSION "1.2.13"
 #define CONFIG_FILE "/etc/devfsd.conf"
 #define MAX_ARGS (6 + 1)
 
@@ -155,8 +165,8 @@
 #define MKACTION(what,when) (struct action_type) {what, when}
 
 #define SYSLOG(level, format, args...) \
-    if (syslog_is_open) syslog (level, format, ##args); \
-    else fprintf (stderr, format, ## args)
+    {if (syslog_is_open) syslog (level, format, ##args); \
+     else fprintf (stderr, format, ## args);}
 
 
 struct permissions_type
